==> nile_api-0.1.2.tar.gz: nile_api-0.1.2/nile_api/api/metrics/filter_metrics_for_entity_type.py <==
import datetime
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.filter_ import Filter
from ...models.metric import Metric
from ...types import UNSET, Response, Unset


def _get_kwargs(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
    from_timestamp: Union[Unset, None, datetime.datetime] = UNSET,
    duration: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/workspaces/{workspace}/metrics/entities/{entity_type}/filter".format(
        client.base_url, workspace=workspace, entity_type=entity_type
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_from_timestamp: Union[Unset, None, str] = UNSET
    if not isinstance(from_timestamp, Unset):
        json_from_timestamp = from_timestamp.isoformat() if from_timestamp else None

    params["from_timestamp"] = json_from_timestamp

    params["duration"] = duration

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[Metric]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = Metric.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[Metric]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
    from_timestamp: Union[Unset, None, datetime.datetime] = UNSET,
    duration: Union[Unset, None, int] = UNSET,
) -> Response[List[Metric]]:
    """List of metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        from_timestamp (Union[Unset, None, datetime.datetime]): The ISO-8601 formatted timestamp
            used to begin searching for matching metrics, i.e., 2018-11-13T20:20:39+00:00. If not
            provided the range will start from the epoch. Results returned are inclusive of this
            timestamp.
        duration (Union[Unset, None, int]): The duration (seconds) added to from_timestamp to
            limit the time range of the query. i.e., the query will be restricting to metric.timestamp
            >= from_timestamp AND metric.timestamp < from_timestamp + duration.  If not provided or
            the duration is <=0 then the end timestamp is set to now
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
        from_timestamp=from_timestamp,
        duration=duration,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
    from_timestamp: Union[Unset, None, datetime.datetime] = UNSET,
    duration: Union[Unset, None, int] = UNSET,
) -> Optional[List[Metric]]:
    """List of metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        from_timestamp (Union[Unset, None, datetime.datetime]): The ISO-8601 formatted timestamp
            used to begin searching for matching metrics, i.e., 2018-11-13T20:20:39+00:00. If not
            provided the range will start from the epoch. Results returned are inclusive of this
            timestamp.
        duration (Union[Unset, None, int]): The duration (seconds) added to from_timestamp to
            limit the time range of the query. i.e., the query will be restricting to metric.timestamp
            >= from_timestamp AND metric.timestamp < from_timestamp + duration.  If not provided or
            the duration is <=0 then the end timestamp is set to now
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    return sync_detailed(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
        from_timestamp=from_timestamp,
        duration=duration,
    ).parsed


async def asyncio_detailed(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
    from_timestamp: Union[Unset, None, datetime.datetime] = UNSET,
    duration: Union[Unset, None, int] = UNSET,
) -> Response[List[Metric]]:
    """List of metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        from_timestamp (Union[Unset, None, datetime.datetime]): The ISO-8601 formatted timestamp
            used to begin searching for matching metrics, i.e., 2018-11-13T20:20:39+00:00. If not
            provided the range will start from the epoch. Results returned are inclusive of this
            timestamp.
        duration (Union[Unset, None, int]): The duration (seconds) added to from_timestamp to
            limit the time range of the query. i.e., the query will be restricting to metric.timestamp
            >= from_timestamp AND metric.timestamp < from_timestamp + duration.  If not provided or
            the duration is <=0 then the end timestamp is set to now
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
        from_timestamp=from_timestamp,
        duration=duration,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
    from_timestamp: Union[Unset, None, datetime.datetime] = UNSET,
    duration: Union[Unset, None, int] = UNSET,
) -> Optional[List[Metric]]:
    """List of metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        from_timestamp (Union[Unset, None, datetime.datetime]): The ISO-8601 formatted timestamp
            used to begin searching for matching metrics, i.e., 2018-11-13T20:20:39+00:00. If not
            provided the range will start from the epoch. Results returned are inclusive of this
            timestamp.
        duration (Union[Unset, None, int]): The duration (seconds) added to from_timestamp to
            limit the time range of the query. i.e., the query will be restricting to metric.timestamp
            >= from_timestamp AND metric.timestamp < from_timestamp + duration.  If not provided or
            the duration is <=0 then the end timestamp is set to now
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    return (
        await asyncio_detailed(
            workspace=workspace,
            entity_type=entity_type,
            client=client,
            json_body=json_body,
            from_timestamp=from_timestamp,
            duration=duration,
        )
    ).parsed

==> nile_api-0.2.8.tar.gz: nile_api-0.2.8/nile_api/api/metrics/filter_metrics_for_entity_type.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.error import Error
from ...models.filter_ import Filter
from ...models.metric import Metric
from ...types import Response


def _get_kwargs(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
) -> Dict[str, Any]:
    url = "{}/workspaces/{workspace}/metrics/entities/{entity_type}/filter".format(
        client.base_url, workspace=workspace, entity_type=entity_type
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[Metric]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = Metric.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    # Nile has a known format for 40X errors, so regardless of the spec, lets return a Nile error
    # Note that the type hint may or may not include Error type
    if response.status_code >= 400 and response.status_code < 500:
        return Error.from_dict(response.json())

    # If it isn't 20X and isn't 40X, we don't know what to do.
    # This is a hard-coded version of https://github.com/openapi-generators/openapi-python-client/pull/593
    raise RuntimeError(f"Unexpected status code: {response.status_code}")


def _build_response(*, response: httpx.Response) -> Response[List[Metric]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
) -> Response[List[Metric]]:
    """List metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
) -> Optional[List[Metric]]:
    """List metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    return sync_detailed(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
) -> Response[List[Metric]]:
    """List metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        entity_type=entity_type,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    workspace: str,
    entity_type: str,
    *,
    client: Client,
    json_body: Filter,
) -> Optional[List[Metric]]:
    """List metrics for the entity matching the filter

    Args:
        workspace (str):
        entity_type (str):
        json_body (Filter):

    Returns:
        Response[List[Metric]]
    """

    return (
        await asyncio_detailed(
            workspace=workspace,
            entity_type=entity_type,
            client=client,
            json_body=json_body,
        )
    ).parsed
